###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

        # Python script for Figures in following paper (c) by W. Yao, L. Puts, K. Williams and D. Lenstra
        # as part of the work published in "An All-Optical Spiking Laser Neuron Integrated in Generic 
        # InP Photonic Circuit Technology" published in Optics Express
        # 
        # This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
        # 
        # You should have received a copy of the license along with this work. If not, see 
        # <https://creativecommons.org/licenses/by-nc-sa/4.0/>.
        
        # Eindhoven Univesity of Technology, Eindhoven, the Netherlands, May 2025
        
        # Contact: l.puts@tue.nl

###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

import numpy as np
import matplotlib.pyplot as plt

plt.rcParams["font.family"] = 'Times New Roman'
plt.rcParams['font.size'] = 13

file_opt='Sample h15b laser l3 LI in uW at 15C2024-04-09_16_02_06.npy'
file_elc='Sample h15b laser l3 VI in V at 15C2024-04-09_16_02_06.npy'

data_opt=np.load(file_opt)
data_elc=np.load(file_elc)

colors=['C0','C1','C2']
labels=['-1.0','-1.10','-1.20']

current=np.linspace(0,70,int(len(data_opt[0])/2))

fig, ax1 = plt.subplots(figsize=(4.5,3))
fig.patch.set_alpha(0)
ax2 = ax1.twinx()

for i in range(1,2):

    ax1.plot(current,data_opt[i,0:int(len(data_opt[0])/2)],color='k',linewidth=2,label='Forward')
    ax1.plot(current,np.flip(data_opt[i,int(len(data_opt[0])/2):int((len(data_opt[0])))]),'--k',linewidth=1,label='Backward')

    
    ax2.plot(current,data_elc[i,0:int(len(data_elc[0])/2)],color='k',linewidth=1,label=str(labels[i])+' V')

ax1.annotate('', xy=(54, 40), xytext=(45, 40), # start the arrow from x=7 and draw towards primary y-axis
            arrowprops=dict(arrowstyle="<-", color='k',linewidth=1.5),zorder=10)
ax1.scatter(55, 40, s=100, facecolors='none', edgecolors='k',linewidth=1.5,zorder=10)
ax2.annotate('', xy=(31, 1.11), xytext=(21, 1.11), # start the arrow from x=7 and draw towards primary y-axis
            arrowprops=dict(arrowstyle="->", color='k',linewidth=1.5),zorder=10)
ax2.scatter(20, 1.11, s=100, facecolors='none', edgecolors='k',linewidth=1.5,zorder=10)


ax1.set_xlim([0,70])
ax1.set_ylim([0,80])
ax1.set_xlabel(r'Gain current [mA]',fontsize=13)
ax1.set_ylabel(r'Optical output power [µW]',fontsize=13)
ax2.set_ylabel(r'Gain voltage [V]',fontsize=13)
ax1.legend()
ax1.grid()
plt.tight_layout()